@@ -169,10 +169,14 @@ function themeReady() {
 			$('#host_id').val(ui.item.id);
 			callBack = $('#call_back').val();
 			if (callBack != 'undefined') {
-				eval(callBack);
-			}else if (typeof applyGraphFilter === 'function') {
+				if (callBack.indexOf('applyFilter') >= 0) {
+					applyFilter();
+				} else if (callBack.indexOf('applyGraphFilter') >= 0) {
+					applyGraphFilter();
+				}
+			} else if (typeof applyGraphFilter === 'function') {
 				applyGraphFilter();
-			}else{
+			} else {
 				applyFilter();
 			}
 		}
@@ -189,7 +193,7 @@ function themeReady() {
 			$('#host').autocomplete('close');
 			clearTimeout(hostTimer);
 			hostOpen = false;
-		}else{
+		} else {
 			clickTimeout = setTimeout(function() {
 				$('#host').autocomplete('search', '');
 				clearTimeout(hostTimer);
@@ -240,7 +244,7 @@ function setMenuVisibility() {
 		if (active != null && active == 'active') {
 			$(this).find('ul').attr('aria-hidden', 'false').attr('aria-expanded', 'true').show();
 			$(this).next('a').show();
-		}else{
+		} else {
 			$(this).find('ul').attr('aria-hidden', 'true').attr('aria-expanded', 'false').hide();
 			$(this).next('a').hide();
 		}
@@ -263,7 +267,7 @@ function setMenuVisibility() {
 
 		id = $(this).closest('.menuitem').attr('id');
 
-		if ($(this).next().is(':visible')){
+		if ($(this).next().is(':visible')) {
 			$(this).next('ul').attr('aria-hidden', 'true').attr('aria-expanded', 'false');
 			$(this).next().slideUp( { duration: 200, easing: 'swing' } );
 			storage.set(id, 'collapsed');
@@ -272,7 +276,7 @@ function setMenuVisibility() {
 			$(this).next().slideToggle( { duration: 200, easing: 'swing' } );
 			if ($(this).next().is(':visible')) {
 				storage.set($(this).closest('.menuitem').attr('id'), 'active');
-			}else{
+			} else {
 				storage.set(id, 'collapsed');
 			}
 		}
