@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -65,6 +65,33 @@ function prime_default_settings() {
 	$_SESSION['settings_primed'] = true;
 }
 
+function install_create_csrf_secret($file) {
+	if (!file_exists($file)) {
+		if (is_writable(dirname($file))) {
+			$r = '';
+
+			for ($i = 0; $i < 32; $i++) {
+				$r .= chr(mt_rand(0, 255));
+			}
+
+			$r .= time() . microtime();
+
+			$secret = sha1($r);
+
+			// Write the file
+			$fh = fopen($file, 'w');
+			fwrite($fh, '<?php $secret = "'.$secret.'";' . PHP_EOL);
+			fclose($fh);
+
+			return true;
+		} else {
+			return false;
+		}
+	}
+
+	return true;
+}
+
 function install_test_local_database_connection() {
 	global $database_type, $database_hostname, $database_username, $database_password, $database_default, $database_type, $database_port, $database_retries, $database_ssl, $database_ssl_key, $database_ssl_cert, $database_ssl_ca;
 
@@ -271,9 +298,11 @@ function db_install_add_cache($status, $sql) {
 	}
 }
 
-function find_best_path($binary_name) {
+function find_search_paths($os = 'unix') {
 	global $config;
-	if ($config['cacti_server_os'] == 'win32') {
+
+	if ($os == 'win32') {
+		$search_suffix = ';';
 		$search_paths = array(
 			'c:/usr/bin',
 			'c:/cacti',
@@ -297,6 +326,7 @@ function find_best_path($binary_name) {
 			'd:/progra~1/spine/bin'
 		);
 	} else {
+		$search_suffix = ':';
 		$search_paths = array(
 			'/bin',
 			'/sbin',
@@ -309,9 +339,35 @@ function find_best_path($binary_name) {
 		);
 	}
 
-	for ($i=0; $i<cacti_count($search_paths); $i++) {
-		if ((file_exists($search_paths[$i] . '/' . $binary_name)) && (is_readable($search_paths[$i] . '/' . $binary_name))) {
-			return $search_paths[$i] . '/' . $binary_name;
+	$env_path = getenv('PATH');
+	if ($env_path) {
+		$search_paths = array_merge(explode($search_suffix,$env_path), $search_paths);
+	}
+
+	$env_php = getenv('PHP_BINDIR');
+	if ($env_php) {
+		$search_paths = array_merge(explode($search_suffix,$env_php), $search_paths);
+	}
+
+	if (!empty($config['php_path'])) {
+		$search_paths = array_merge(explode($search_suffix,$config['php_path']), $search_paths);
+	}
+
+	$search_paths = array_unique($search_paths);
+	return $search_paths;
+}
+
+function find_best_path($binary_name) {
+	global $config;
+
+	$search_paths = find_search_paths($config['cacti_server_os']);
+
+	if (cacti_sizeof($search_paths)) {
+		foreach($search_paths as $path) {
+			$desired_path = $path . '/' . $binary_name;
+			if ((@file_exists($desired_path)) && (@is_readable($desired_path))) {
+				return $desired_path;
+			}
 		}
 	}
 	return '';
